@@ -1,97 +1,11 @@
 import logging
-from datetime import datetime
 
+from .models import *
 from .pf_interaction import pf_interaction
 
 logger = logging.getLogger(__name__)
 
 PAGE_LIMIT = 500
-ACCOUNT_ID = 264304
-MAX_REQUESTS_PER_FUNCTION = 100
-NO_PROJECT_ID = 0
-NO_CATEGORY_ID = 0
-
-
-class OperationPart:
-    def __init__(self,
-                 operation_category_id: int,
-                 project_id: int,
-                 value: float
-                 ):
-        self.value = value
-        if operation_category_id == 0:
-            self.operation_category_id = None
-        else:
-            self.operation_category_id = operation_category_id
-        if project_id == 0:
-            self.project_id = None
-        else:
-            self.project_id = project_id
-
-
-class MoveOperation:
-    def __init__(self,
-                 is_committed: bool,
-                 date: datetime,
-                 comment: str,
-                 value_outcome: float,
-                 value_income: float,
-                 account_id_income: int,
-                 account_id_outcome: int,
-                 external_id=None
-                 ):
-        self.date = date
-        self.is_committed = is_committed
-        self.params = {
-            "debitingDate": date.strftime('%Y-%m-%d'),
-            "admissionDate": date.strftime('%Y-%m-%d'),
-            "admissionAccountId": account_id_income,  # Счет зачисления
-            "debitingAccountId": account_id_outcome,  # Счет списания
-            "admissionValue": value_income,  # Сумма зачисления
-            "debitingValue": value_outcome,  # Сумма списания
-            "isCommitted": False,
-            "externalId": external_id,
-            "comment": comment}
-        if is_committed:
-            self.params.update({
-                "calculationDate": date.strftime('%Y-%m-%d'),
-                "isCalculationCommitted": True,
-                "isCommitted": True})
-
-
-class Operation:
-    def __init__(self,
-                 is_committed: bool,
-                 date: datetime,
-                 comment: str,
-                 value: float,
-                 account_id: int,
-                 external_id=None
-                 ):
-        self.date = date
-        self.is_committed = is_committed
-        self.params = {
-            "operationDate": date.strftime('%Y-%m-%d'),
-            "accountId": account_id,
-            "value": value,
-            "isCommitted": False,
-            "externalId": external_id,
-            "comment": comment,
-            "items": list()}
-        if is_committed:
-            self.params.update({
-                "calculationDate": date.strftime('%Y-%m-%d'),
-                "isCalculationCommitted": True,
-                "isCommitted": True})
-
-    def append_item(self, item: OperationPart):
-        self.params['items'].append({
-            "calculationDate": self.date.strftime('%Y-%m-%d'),
-            "isCalculationCommitted": self.is_committed,
-            "operationCategoryId": item.operation_category_id,
-            "projectId": item.project_id,
-            "value": item.value
-        })
 
 
 def get_currencies():
@@ -102,7 +16,7 @@ def get_currencies():
     return items
 
 
-def get_operations(account_id = None):
+def get_operations(account_id=None):
     path = f'/api/v1/operations'
     params = {'paging.limit': PAGE_LIMIT,
               'paging.offset': 0}
@@ -204,6 +118,13 @@ def create_move_operation(operation: MoveOperation):
     return res.json()['data']
 
 
+def create_account(account: Account):
+    path = f'/api/v1/operations/create_account'
+    data = account.dict()
+    res, _ = pf_interaction.request('post', path, data=data)
+    return res.json()['data']
+
+
 def get_allowed_entities(rule, entities, ident_by):
     allowed_ids = None
     if rule['accessRuleType'] == 'Allowed':
@@ -288,7 +209,3 @@ def get_balances():
                          'title': account['title'],
                          'balance': balance})
     return balances
-
-
-
-
